import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'docutain_sdk_platform_interface.dart';

/// An implementation of [DocutainSdkPlatform] that uses method channels.
class MethodChannelDocutainSdk extends DocutainSdkPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('docutain_sdk');

  @override
  Future<bool> initSDK(String licenseKey) {
    //return false if value is null
    return methodChannel.invokeMethod<bool>('initSDK', {
      'licenseKey': licenseKey
    }).then<bool>((bool? value) => value ?? false);
  }

  @override
  Future<String> getLastError() {
    return methodChannel.invokeMethod<String>('getLastError')
        .then<String>((String? value) => value ?? "");
  }

  @override
  Future<bool> scanDocument() {
    return methodChannel.invokeMethod<bool>('scanDocument')
        .then<bool>((bool? value) => value ?? false);
  }

  @override
  Future<File?> writePDF(String path, String fileName, bool overwrite) async {
    String? returnPath = await methodChannel.invokeMethod<String>('writePDF', {
      'path': path,
      'fileName': fileName,
      'overwrite': overwrite
    });
    if (returnPath != null) {
      return Future<File?>.value(File(returnPath));
    } else {
      return Future<File?>.value(null);
    }
  }
}
